#
# Conditional build:
%bcond_with	tests		# build with tests

Summary:	Engine for processing 3D models into G-code instructions for 3D printers
Summary(pl.UTF-8):	Silnik do przetwarzania modeli 3D na instrukcje G-code dla drukarek 3D
# keep in sync with cura, libArcus, libSavitar, python3-Uranium
Name:		CuraEngine
Version:	4.13.2
Release:	1
Epoch:		1
License:	AGPL v3
Group:		Applications/Engineering
#Source0Download: https://github.com/Ultimaker/CuraEngine/tags
Source0:	https://github.com/Ultimaker/CuraEngine/archive/%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	85b46d4282dc061345d4efda822fae19
Source1:	https://raw.githubusercontent.com/nothings/stb/master/stb_image.h
# Source1-md5:	27932e6fb3a2f26aee2fc33f2cb4e696
Patch0:		%{name}-includes.patch
Patch1:		%{name}-static-libstdcpp.patch
Patch2:		local-stb.patch
URL:		https://github.com/Ultimaker/CuraEngine
BuildRequires:	cmake >= 3.8.0
%{?with_tests:BuildRequires:  gmock-devel >= 1.8.0}
BuildRequires:	libArcus-devel = %{version}
BuildRequires:	libgomp-devel
BuildRequires:	libstdc++-devel >= 6:7
BuildRequires:	polyclipping-devel >= 6.1.2
BuildRequires:	protobuf-devel >= 3.0.0
%{?with_tests:BuildRequires:  python3 >= 1:3}
BuildRequires:	rapidjson-devel
%requires_eq	libArcus
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
CuraEngine is a C++ console application for 3D printing G-code
generation. It has been made as a better and faster alternative to the
old Skeinforge engine.

This is just a console application for G-code generation. For a full
graphical application look at cura with is the graphical frontend for
CuraEngine.

%description -l pl.UTF-8
CuraEngine to aplikacja konsolowa C++ do generowania intrukcji G-code
dla drukarek 3D. Powstała jako lepsza i szybsza alternatywa dla
starego silnika Skeinforge.

To jest tylko aplikacja konsolowa do generowania kodu. Pełna graficzna
aplikacja, będąca graficznym interfejsem do CuraEngine, znajduje się w
pakiecie cura.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

mkdir stb
cp -p %{SOURCE1} stb/

# bundled libraries
%{__rm} -rf libs
%{__sed} -i 's|#include <clipper/clipper.hpp>|#include <polyclipping/clipper.hpp>|' src/utils/*.h src/*.cpp

# The -DCURA_ENGINE_VERSION does not work, so we sed-change the default value
%{__sed} -i 's/"DEV"/"%{version}"/' src/settings/Settings.h

%build
mkdir build
cd build
%cmake .. \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	%{?with_tests:-DBUILD_TESTS:BOOL=ON} \
	-DCURA_ENGINE_VERSION:STRING=%{version} \
	-DSET_RPATH:BOOL=OFF \
	-DStb_INCLUDE_DIRS:STRING="$(pwd)/.." \
	-DUSE_SYSTEM_LIBS:BOOL=ON

%{__make}

%{?with_tests:%{__make} test}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.md
%attr(755,root,root) %{_bindir}/%{name}
%changelog
* Thu Oct 03 2024 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/CuraEngine.git;a=log;h=master

* Thu Oct 03 2024 Jakub Bogusz <qboosh@pld-linux.org> 87694fc
- added includes patch (missing include)

* Fri Sep 27 2024 Jakub Bogusz <qboosh@pld-linux.org> 09150cf
- updated to 4.13.2

* Fri Jul 08 2022 Jakub Bogusz <qboosh@pld-linux.org> 6f629d4
- release 5

* Fri Jan 22 2021 Jan Rękorajski <baggins@pld-linux.org> c46379e
- release 4 (by relup.sh)

* Sun Sep 27 2020 Jakub Bogusz <qboosh@pld-linux.org> 84b0a03
- updated static-libstdcpp patch is back; release 3

* Mon Jun 01 2020 Jan Rękorajski <baggins@pld-linux.org> f2b7915
- release 2 (by relup.sh)

* Wed Apr 08 2020 Jan Rękorajski <baggins@pld-linux.org> 5ed8cdd
- up to 4.5.0

* Wed Apr 08 2020 Jan Rękorajski <baggins@pld-linux.org> 43d9bea
- release 6 (by relup.sh)

* Wed Jul 31 2019 Jakub Bogusz <qboosh@pld-linux.org> 4c96bf6
- release 5 (rebuild with protobuf 3.9.0)
- drop LICENSE from docs (copy of generic AGPLv3 text)

* Fri Apr 19 2019 Jan Rękorajski <baggins@pld-linux.org> 42d9950
- release 4 (by relup.sh)

* Sun Mar 17 2019 Jan Rękorajski <baggins@pld-linux.org> e686161
- release 3 (by relup.sh)

* Sun Nov 04 2018 Jan Rękorajski <baggins@pld-linux.org> e36aaec
- CuraEngine "requires" stb library, but what it really wants is a single header,
  package it here to avoid fetching the whole thing at build time
- rel 2

* Sun Nov 04 2018 Jan Rękorajski <baggins@pld-linux.org> 7eddc54
- up to 3.5.1

* Sat Oct 13 2018 Jakub Bogusz <qboosh@pld-linux.org> 4b3b0a4
- pl, release 3 (rebuild with protobuf 3.6)

* Wed Dec 13 2017 Jan Rękorajski <baggins@pld-linux.org> efa3bde
- release 2 (by relup.sh)

* Sat May 13 2017 Jan Rękorajski <baggins@pld-linux.org> 913bfb5
- updated to 2.5.0

* Fri May 15 2015 Elan Ruusamäe <glen@delfi.ee> 880c7dc
- cleanups

* Thu May 14 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> fd41772
- initial, from FC

